@@ -7,7 +7,9 @@ use Catalyst qw/
 /;
 
 use base qw/Catalyst/;
-__PACKAGE__->engine_class('RemoteTestEngine');
+unless ($Catalyst::VERSION >= 5.89000) {
+    __PACKAGE__->engine_class('RemoteTestEngine');
+}
 __PACKAGE__->config(
     'Plugin::Authentication' => {
         default_realm => 'remote',
@@ -28,8 +30,11 @@ __PACKAGE__->config(
         },
     },
 );
-
 __PACKAGE__->setup;
+if ($Catalyst::VERSION >= 5.89000) {
+    require RemoteTestEngineRole;
+    RemoteTestEngineRole->meta->apply(__PACKAGE__->engine);
+}
 
 1;
 
